==> openshift-model-monitoring-5.10.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeTargetsFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ProbeTargetsFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent<A>{
  public ProbeTargetsFluentImpl() {
  }
  public ProbeTargetsFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargets instance) {
    this.withIngress(instance.getIngress()); 
    this.withStaticConfig(instance.getStaticConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder ingress;
  private io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder staticConfig;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress getIngress() {
    return this.ingress!=null?this.ingress.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress buildIngress() {
    return this.ingress!=null?this.ingress.build():null;
  }
  public A withIngress(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress ingress) {
    _visitables.get("ingress").remove(this.ingress);
    if (ingress!=null){ this.ingress= new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder(ingress); _visitables.get("ingress").add(this.ingress);} return (A) this;
  }
  public java.lang.Boolean hasIngress() {
    return this.ingress != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<A> withNewIngress() {
    return new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluentImpl.IngressNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<A> withNewIngressLike(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluentImpl.IngressNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<A> editIngress() {
    return withNewIngressLike(getIngress());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<A> editOrNewIngress() {
    return withNewIngressLike(getIngress() != null ? getIngress(): new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<A> editOrNewIngressLike(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress item) {
    return withNewIngressLike(getIngress() != null ? getIngress(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStaticConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig getStaticConfig() {
    return this.staticConfig!=null?this.staticConfig.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig buildStaticConfig() {
    return this.staticConfig!=null?this.staticConfig.build():null;
  }
  public A withStaticConfig(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig staticConfig) {
    _visitables.get("staticConfig").remove(this.staticConfig);
    if (staticConfig!=null){ this.staticConfig= new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder(staticConfig); _visitables.get("staticConfig").add(this.staticConfig);} return (A) this;
  }
  public java.lang.Boolean hasStaticConfig() {
    return this.staticConfig != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<A> withNewStaticConfig() {
    return new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluentImpl.StaticConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<A> withNewStaticConfigLike(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluentImpl.StaticConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<A> editStaticConfig() {
    return withNewStaticConfigLike(getStaticConfig());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<A> editOrNewStaticConfig() {
    return withNewStaticConfigLike(getStaticConfig() != null ? getStaticConfig(): new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<A> editOrNewStaticConfigLike(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig item) {
    return withNewStaticConfigLike(getStaticConfig() != null ? getStaticConfig(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProbeTargetsFluentImpl that = (ProbeTargetsFluentImpl) o;
    if (ingress != null ? !ingress.equals(that.ingress) :that.ingress != null) return false;
    if (staticConfig != null ? !staticConfig.equals(that.staticConfig) :that.staticConfig != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ingress,  staticConfig,  additionalProperties,  super.hashCode());
  }
  public class IngressNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    IngressNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder(this, item);
    }
    IngressNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder builder;
    public N and() {
      return (N) ProbeTargetsFluentImpl.this.withIngress(builder.build());
    }
    public N endIngress() {
      return and();
    }
    
  }
  public class StaticConfigNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StaticConfigNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder(this, item);
    }
    StaticConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder builder;
    public N and() {
      return (N) ProbeTargetsFluentImpl.this.withStaticConfig(builder.build());
    }
    public N endStaticConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeTargetsFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ProbeTargetsFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent<A>{
  public ProbeTargetsFluentImpl() {
  }
  public ProbeTargetsFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargets instance) {
    this.withIngress(instance.getIngress()); 
    this.withStaticConfig(instance.getStaticConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder ingress;
  private io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder staticConfig;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress getIngress() {
    return this.ingress!=null?this.ingress.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress buildIngress() {
    return this.ingress!=null?this.ingress.build():null;
  }
  public A withIngress(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress ingress) {
    _visitables.get("ingress").remove(this.ingress);
    if (ingress!=null){ this.ingress= new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder(ingress); _visitables.get("ingress").add(this.ingress);} return (A) this;
  }
  public java.lang.Boolean hasIngress() {
    return this.ingress != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<A> withNewIngress() {
    return new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluentImpl.IngressNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<A> withNewIngressLike(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluentImpl.IngressNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<A> editIngress() {
    return withNewIngressLike(getIngress());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<A> editOrNewIngress() {
    return withNewIngressLike(getIngress() != null ? getIngress(): new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<A> editOrNewIngressLike(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress item) {
    return withNewIngressLike(getIngress() != null ? getIngress(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStaticConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig getStaticConfig() {
    return this.staticConfig!=null?this.staticConfig.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig buildStaticConfig() {
    return this.staticConfig!=null?this.staticConfig.build():null;
  }
  public A withStaticConfig(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig staticConfig) {
    _visitables.get("staticConfig").remove(this.staticConfig);
    if (staticConfig!=null){ this.staticConfig= new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder(staticConfig); _visitables.get("staticConfig").add(this.staticConfig);} return (A) this;
  }
  public java.lang.Boolean hasStaticConfig() {
    return this.staticConfig != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<A> withNewStaticConfig() {
    return new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluentImpl.StaticConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<A> withNewStaticConfigLike(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluentImpl.StaticConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<A> editStaticConfig() {
    return withNewStaticConfigLike(getStaticConfig());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<A> editOrNewStaticConfig() {
    return withNewStaticConfigLike(getStaticConfig() != null ? getStaticConfig(): new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<A> editOrNewStaticConfigLike(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig item) {
    return withNewStaticConfigLike(getStaticConfig() != null ? getStaticConfig(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProbeTargetsFluentImpl that = (ProbeTargetsFluentImpl) o;
    if (ingress != null ? !ingress.equals(that.ingress) :that.ingress != null) return false;
    if (staticConfig != null ? !staticConfig.equals(that.staticConfig) :that.staticConfig != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ingress,  staticConfig,  additionalProperties,  super.hashCode());
  }
  public class IngressNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.IngressNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    IngressNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngress item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder(this, item);
    }
    IngressNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetIngressBuilder builder;
    public N and() {
      return (N) ProbeTargetsFluentImpl.this.withIngress(builder.build());
    }
    public N endIngress() {
      return and();
    }
    
  }
  public class StaticConfigNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetsFluent.StaticConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StaticConfigNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfig item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder(this, item);
    }
    StaticConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.ProbeTargetStaticConfigBuilder builder;
    public N and() {
      return (N) ProbeTargetsFluentImpl.this.withStaticConfig(builder.build());
    }
    public N endStaticConfig() {
      return and();
    }
    
  }
  
}
